@@ -30,9 +30,26 @@ test_that("Plotting mkinfit, mmkin and mixed model objects is reproducible", {
   plot_err_sfo_sfo <- function() plot_err(f_sfo_sfo_desolve)
   vdiffr::expect_doppelganger("plot_err for FOCUS D", plot_err_sfo_sfo)
 
+  # UBA datasets
+  ds_uba <- lapply(experimental_data_for_UBA_2019[6:10],
+    function(x) subset(x$data[c("name", "time", "value")]))
+  names(ds_uba) <- paste("Dataset", 6:10)
+  sfo_sfo_uba <- mkinmod(parent = mkinsub("SFO", "A1"),
+    A1 = mkinsub("SFO"), quiet = TRUE)
+  dfop_sfo_uba <- mkinmod(parent = mkinsub("DFOP", "A1"),
+    A1 = mkinsub("SFO"), quiet = TRUE)
+  f_uba_mmkin <- mmkin(list("DFOP-SFO" = dfop_sfo_uba),
+    ds_uba, quiet = TRUE, cores = n_cores)
+  f_uba_dfop_sfo_mixed <- mixed(f_uba_mmkin["DFOP-SFO", ])
+
+  f_uba_dfop_sfo_saem <- saem(f_uba_mmkin["DFOP-SFO", ], quiet = TRUE, transformations = "saemix")
+
   plot_biphasic_mmkin <- function() plot(f_uba_dfop_sfo_mixed)
   vdiffr::expect_doppelganger("mixed model fit for mmkin object", plot_biphasic_mmkin)
 
+  plot_biphasic_saem_s <- function() plot(f_uba_dfop_sfo_saem)
+  vdiffr::expect_doppelganger("mixed model fit for saem object with saemix transformations", plot_biphasic_saem_s)
+
   skip_on_travis()
 
   plot_biphasic_nlme <- function() plot(dfop_nlme_1)
@@ -41,6 +58,10 @@ test_that("Plotting mkinfit, mmkin and mixed model objects is reproducible", {
   #plot_biphasic_mmkin <- function() plot(mixed(mmkin_biphasic))
   # Biphasic fits with lots of data and fits have lots of potential for differences
   plot_biphasic_nlme <- function() plot(nlme_biphasic)
+  #plot_biphasic_saem_s <- function() plot(saem_biphasic_s)
+  plot_biphasic_saem_m <- function() plot(saem_biphasic_m)
+
+  vdiffr::expect_doppelganger("mixed model fit for saem object with mkin transformations", plot_biphasic_saem_m)
 
   # different results when working with eigenvalues
   plot_errmod_fit_D_obs_eigen <- function() plot_err(fit_D_obs_eigen, sep_obs = FALSE)
